==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Borrar rexistros</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Recargar</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Estás seguro/a que quere borrar os rexistros?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 días</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meses</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportar</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emerxencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alertar</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuración</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Inicar sesión</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXTO (* .txt) ;; Doc (* .doc) ;; Xls (* .xls) ;; Html (* .html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportando...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportar con éxito</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportar ficheiros</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Período:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista de aplicativos:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estados:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rexistro de arranque</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Rexistro de parada</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Rexistro do inicio de sesión</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuración</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emerxencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alertar</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>O ficheiro de rexistro está baleiro</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de rexistros</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Visor de rexistros é unha ferramenta útil para ver os rexistros do sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Sen resultados de busca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proceso</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data e tempo</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo de evento</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proceso:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data e tempo:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Información:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data e tempo</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Rexistro do sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Rexistro do núcleo</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Rexistro do arranque</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Rexistro dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Rexistro Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Rexistro Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Rexistro de aplicativos</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Evento de apagado-arranque</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.10+ds1.orig.tar.xz: deepin-log-viewer-6.5.10/translations/deepin-log-viewer_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Borrar rexistros</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Recargar</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Estás seguro/a que quere borrar os rexistros?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 días</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meses</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emerxencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alertar</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuración</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Inicar sesión</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super crítico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Rastro</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Autenticación de identidade</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Control de acceso discrecional</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Control de acceso obligatorio</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Remoto</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Auditoría de documentos</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXTO (* .txt) ;; Doc (* .doc) ;; Xls (* .xls) ;; Html (* .html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportando...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportar con éxito</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>A exportación fallou</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>O directorio de exportación non está disponible. Por favor, escolle outro directorio para a operación de exportación.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportar ficheiros</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Período:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estados:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rexistro de arranque</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Rexistro de parada</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Rexistro do inicio de sesión</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Tipo de auditoría:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Aplicación:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Submódulo:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuración</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emerxencia</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alertar</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Rastro</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super crítico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>O ficheiro de rexistro está baleiro</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de rexistros</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Visor de rexistros é unha ferramenta útil para ver os rexistros do sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Sen resultados de busca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proceso</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data e tempo</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo de evento</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuario</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proceso:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data e tempo:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Información:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Hora de modificación</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Ficheiro de núcleo</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Nome de usuario </translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Desprazamento</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data e tempo</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Rexistro do sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Rexistro do núcleo</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Rexistro do arranque</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Rexistro dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Rexistro Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Rexistro Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Rexistro de aplicativos</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Evento de apagado-arranque</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registos dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Outros registos</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Logus customizados</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Logus de auditoría</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Logus de derrumbe</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>Non foi posíbel obter información de fallo. Instale systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Non ten permiso para ver o mesmo</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Nivel de seguridade do sistema actual: elevado
somos só os administradores os que pode ver o log de auditoría</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation>O log de auditoría non existe.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Exportar logus ao camiño especificado</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>CAMIÑO</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Exportar logus de tipos especificados</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Exportar logus de aplicacións desenvolvidas por si mesmas especificadas</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>APLICACIÓN DESARROLLADA POR SI MESMA</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Exportar logus dentro dun período de tempo especificado</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>PERIODO</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Exportar logus dentro dun nivel de depuración especificado</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>NÍVEL</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>ESTATUS DE INICIO</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Exportar logus de inicio (no-klu) dentro dun estato especificado</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Exportar logus de inicio/apagado de evento ou de auditoría dentro dun tipo de evento especificado</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>TIPO DE EVENTO</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Exportar logus baseados nos resultados da busca por palabras clave</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>PALABRA CLAVE</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Reportar informacións de derrumbe.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Exportar logus baseados no submodelo da aplicación</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>SUBMÓDULO</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Intervalo de actualización</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 seg</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Sin actualización</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exportar todo</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Actualizar agora</translation>
    </message>
</context>
</TS>
